==> typeflows-gradle-0.10.0-beta-sources.jar: io/typeflows/gradle/tasks/InstallCopilotTask.kt <==
/*
 * Copyright (c) 2025 Incerto Group Ltd
 * This is beta software under the Typeflows Beta License.
 * See LICENSE file for details.
 *
 * For more information, visit https://typeflows.io/license
 */

package io.typeflows.gradle.tasks

import io.typeflows.plugin.TypeflowsRunner
import io.typeflows.plugin.tasks.InstallCopilot
import org.gradle.api.DefaultTask
import org.gradle.api.file.ConfigurableFileCollection
import org.gradle.api.file.DirectoryProperty
import org.gradle.api.tasks.InputFiles
import org.gradle.api.tasks.OutputDirectory
import org.gradle.api.tasks.PathSensitive
import org.gradle.api.tasks.PathSensitivity.RELATIVE
import org.gradle.api.tasks.TaskAction

abstract class InstallCopilotTask : DefaultTask() {
    @get:InputFiles
    @get:PathSensitive(RELATIVE)
    abstract val classpath: ConfigurableFileCollection

    @get:OutputDirectory
    abstract val copilotDirectory: DirectoryProperty

    @TaskAction
    fun typeflowsInstallCopilot() {
        TypeflowsRunner.execute(
            classpathElements = classpath.files.map { it.absolutePath },
            typeflowsClassName = InstallCopilot::class.qualifiedName!!,
            outputDirectory = copilotDirectory.get().asFile,
            onSuccess = { logger.lifecycle("✅ Copilot instructions installed: .github/instructions/ and .github/prompts/") },
            onFailure = { exception -> logger.lifecycle("❌ Failed to install Copilot instructions (${exception.javaClass.simpleName}): ${exception.message}") }
        )
    }
}

==> typeflows-gradle-0.11.0-beta-sources.jar: io/typeflows/gradle/tasks/InstallCopilotTask.kt <==
/*
 * Copyright (c) 2025 Incerto Group Ltd
 * This is beta software under the Typeflows Beta License.
 * See LICENSE file for details.
 *
 * For more information, visit https://typeflows.io/license
 */

package io.typeflows.gradle.tasks

import io.typeflows.plugin.TypeflowsRunner
import io.typeflows.plugin.tasks.InstallCopilot
import org.gradle.api.DefaultTask
import org.gradle.api.file.ConfigurableFileCollection
import org.gradle.api.file.DirectoryProperty
import org.gradle.api.tasks.InputFiles
import org.gradle.api.tasks.OutputDirectory
import org.gradle.api.tasks.PathSensitive
import org.gradle.api.tasks.PathSensitivity.RELATIVE
import org.gradle.api.tasks.TaskAction

abstract class InstallCopilotTask : DefaultTask() {
    @get:InputFiles
    @get:PathSensitive(RELATIVE)
    abstract val classpath: ConfigurableFileCollection

    @get:OutputDirectory
    abstract val targetDirectory: DirectoryProperty

    @TaskAction
    fun typeflowsInstallCopilot() {
        TypeflowsRunner.execute(
            classpathElements = classpath.files.map { it.absolutePath },
            typeflowsClassName = InstallCopilot::class.qualifiedName!!,
            outputDirectory = targetDirectory.get().asFile,
            onSuccess = { logger.lifecycle("✅ Copilot instructions installed: .github/instructions/ and .github/prompts/") },
            onFailure = { exception -> logger.lifecycle("❌ Failed to install Copilot instructions (${exception.javaClass.simpleName}): ${exception.message}") }
        )
    }
}
